@@ -1,18 +1,21 @@
-/* $Id: behaviour.js 75 2008-09-06 15:40:09Z pjf $ */
+/* $Id: behaviour.js 503 2008-09-22 20:20:56Z pjf $ */
 
-var State = new Class({
+var State = new Class( {
    options: {
+      assets    : null,
       accordion : null,
       cookies   : null,
       linkFade  : null,
       scroller  : false,
+      slider    : null,
       tips      : null
    },
 
    initialize: function( options ) {
       this.setOptions( options );
-      this.cookies   = new Cookies( { path  : options.path,
-                                      prefix: options.prefix } );
+      this.assets  = options.assets;
+      this.cookies = new Cookies( { path  : options.path,
+                                    prefix: options.prefix } );
    },
 
    getAccordionHeight: function( elem ) {
@@ -21,9 +24,10 @@ var State = new Class({
       return Math.max( 1, height );
    },
 
-   resize: function() {
-      var append, content, elem, elemHeight, elemWidth, height = 5;
-      var h = window.getHeight(), w = window.getWidth();
+   resize: function( changed ) {
+      var append, content, elem;
+      var elemHeight, elemWidth, grippy_height, offset, sb_height;
+      var height = 5, h = window.getHeight(), w = window.getWidth();
 
       if (!isPopup) {
          this.cookies.set( 'width',  w );
@@ -56,16 +60,31 @@ var State = new Class({
       if (elem = $( 'sideBarDisp' )) {
          elem.setStyle( 'marginBottom', height + 'px' );
 
+         // Calculate and set vertical offset for side bar grippy
+         sb_height = elem.getSize().size.y;
+         grippy_height = $( 'sideBarGrippy' ).getSize().size.y;
+         offset = Math.max( 1, Math.round( sb_height / 2 )
+                            - Math.round( grippy_height / 2 ) );
+         $( 'sideBarGrippy' ).setStyle( 'marginTop', offset + 'px' );
+
          if (this.accordion) {
             this.accordion.resize( this.getAccordionHeight( elem ), null );
          }
 
-         if (elem.getStyle( 'display' ) != 'none') {
-            elemWidth = elem.getStyle( 'width' ).toInt();
-            content.setStyle( 'marginLeft', elemWidth + 'px' );
-            if (this.accordion) this.accordion.reload();
+         if (this.cookies.get( 'sideBar' )) {
+            if (changed) {
+               elemWidth = elem.getStyle( 'width' ).toInt();
+               this.cookies.set( 'sideBarWidth',  elemWidth );
+               this.slider.wrapper.setStyle( 'width', elemWidth + 'px' );
+            }
+            else {
+               elemWidth = this.cookies.get( 'sideBarWidth' );
+            }
          }
-         else { content.setStyle( 'marginLeft', '0px' ) }
+         else { elemWidth = 0 }
+
+         elem.setStyle( 'width', elemWidth + 'px' );
+         content.setStyle( 'marginLeft', elemWidth + 'px' );
       }
       else { content.setStyle( 'marginLeft', '0px' ) }
 
@@ -79,7 +98,8 @@ var State = new Class({
    },
 
    setState: function( first_fld ) {
-      var cookie_ref, cookies, elem, height, i, p0, p1, pair, sbs = false;
+      var cookie_ref, cookies, elem, height, i, p0, p1, pair;
+      var sb_panel = 0, sb_state = false, sb_width = 150;
 
       /* Initialize the fading links event handlers */
       this.linkFade  = new LinkFader( { links: document.links,
@@ -91,9 +111,9 @@ var State = new Class({
 
          for (i = 0; i < cookies.length; i++) {
             if (cookies[i]) {
-               pair = cookies[i].split( '~' );
-               p0 = unescape( pair[0] );
-               p1 = unescape( pair[1] );
+               pair = cookies[ i ].split( '~' );
+               p0 = unescape( pair[ 0 ] );
+               p1 = unescape( pair[ 1 ] );
 
                /* Restore state of any checkboxes whose ids end in Box */
                if (elem = $( p0 + 'Box' )) {
@@ -108,33 +128,103 @@ var State = new Class({
                /* Restore the source URL for elements whose ids end in Img */
                if (elem = $( p0 + 'Img' )) { if (p1) elem.src = p1; }
 
-               /* Remember the state of the sidebar being open or closed */
-               if (p0 == 'sideBar') sbs = true;
+               /* Recover the width and panel number of the sidebar */
+               if (p0 == 'sideBar') sb_state = true;
+               if (p0 == 'sideBarWidth') sb_width = p1;
+               if (p0 == 'sideBarPanel') sb_panel = p1;
             }
          }
       }
 
+      /* If this page has a side bar */
       if (elem = $( 'sideBarDisp' )) {
+         if (!this.cookies.get( 'sideBarWidth' )) {
+            this.cookies.set( 'sideBarWidth', '150' );
+         }
+
          height = this.getAccordionHeight( elem );
 
+         /* Setup the slide in/out effect */
+         this.slider = new Fx.Slide( 'sideBarContainer', {
+            mode: 'horizontal',
+            onComplete: function() {
+               var sb_image = $( 'sideBarImg' );
+
+               /* When the effect is complete toggle the state */
+               if (this.cookies.get( 'sideBar' )) {
+                  if (sb_image) sb_image.src = this.assets + 'pushedpin.gif';
+
+                  panel = this.cookies.get( 'sideBarPanel' );
+                  this.accordion.reload( panel );
+                  this.accordion.display( panel );
+               }
+               else {
+                  if (sb_image) sb_image.src = this.assets + 'pushpin.gif';
+
+                  this.resize();
+               }
+            }.bind( this ),
+         } );
+
+         /* Setup the event handler to turn the side bar on/off */
+         $( 'sideBar' ).addEvent( 'click', function( e ) {
+            if (!this.cookies.get( 'sideBar' )) {
+               this.cookies.set( 'sideBar', this.assets + 'pushedpin.gif' );
+               this.resize();
+               e = Event( e );
+               this.slider.slideIn();
+               e.stop();
+            }
+            else {
+               this.cookies.delete( 'sideBar' );
+               e = Event( e );
+               this.slider.slideOut();
+               e.stop();
+            }
+         }.bind( this ) );
+
+         /* Setup the horizontal resize grippy for the side bar */
+         $( 'sideBarGrippy' ).addEvent( 'mousedown', function( sideBar ) {
+            sideBar.makeResizable( {
+               modifiers:             { x: 'width', y: false },
+               limit:                 { x: [ 150, 450 ] },
+               onComplete: function() { this.detach() },
+               onDrag:     function() { this.resize( true ) }.bind( this )
+            } );
+         }.bind( this, elem ) );
+
+         /* Create an Accordion widget in the side bar */
          this.accordion
             = new Accordion( 'div.sideBarHeader', 'div.sideBarPanel', {
                fixedHeight : height,
                opacity     : false,
-               onActive    : function(toggler, element){
+               onActive    : function( toggler, element ) {
                   toggler.setStyle( 'background-color', '#663' );
                   toggler.setStyle( 'color', '#FFC' );
+                  stateObj.cookies.set( 'sideBarPanel',
+                                        this.togglers.indexOf( toggler ) );
                },
-               onBackground: function(toggler, element){
+               onBackground: function( toggler, element ) {
                   toggler.setStyle( 'background-color', '#CC9' );
                   toggler.setStyle( 'color', '#000' );
                }
-            }, $( 'accordionDiv' ));
+            }, $( 'accordionDiv' ) );
 
-         if (sbs == false) elem.setStyle( 'display', 'none' );
+         /* Redisplay and reload the last accordion side bar panel */
+         if (sb_state) this.accordion.reload( sb_panel );
+
+         this.accordion.display( sb_panel );
       }
 
-      this.tips = new Tips( $$( '.tips' ), { showDelay: 666 } );
+      this.tips = new Tips( $$( '.tips' ), {
+         initialize: function() {
+		      this.fx = new Fx.Style( this.toolTip, 'opacity',
+               { duration: 500, wait: false } ).set( 0 );
+         },
+	      onShow:     function( toolTip ) { this.fx.start( 1 ) },
+         onHide:     function( toolTip ) { this.fx.start( 0 ) },
+         showDelay:  666
+      } );
 
       if (this.scroller) {
          this.scroller
@@ -165,7 +255,7 @@ var State = new Class({
          elem.setStyle( 'display', 'none' ); this.cookies.delete( e.id );
       }
       else {
-         elem.setStyle( 'display', '' ); this.cookies.set( e.id, true );
+         elem.setStyle( 'display', '' ); this.cookies.set( e.id, 'true' );
       }
 
       this.resize();
@@ -239,7 +329,7 @@ var State = new Class({
 
       this.resize();
    }
-});
+} );
 
 State.implement( new Options );
 
@@ -249,7 +339,8 @@ var freeListObj    = new FreeList();
 var groupMemberObj = new GroupMember();
 var loadMoreObj    = new LoadMore(      { url   : url } );
 var serverObj      = new ServerMethods( { url   : url } );
-var stateObj       = new State(         { path  : sessionPath,
+var stateObj       = new State(         { assets: assetsPath,
+                                          path  : sessionPath,
                                           prefix: sessionPrefix } );
 var submitObj      = new SubmitUtils(   { path  : sessionPath,
                                           prefix: sessionPrefix } );
@@ -259,4 +350,4 @@ var windowObj      = new WindowUtils(   { path  : sessionPath,
 
 if (target && target == 'top') windowObj.placeOnTop();
 
-onresize = stateObj.resize();
+onresize = stateObj.resize( true );
