@@ -1,20 +1,22 @@
 package HTML::FormWidgets::File;
 
-# @(#)$Id: File.pm 33 2008-05-17 23:36:47Z pjf $
+# @(#)$Id: File.pm 95 2008-09-28 22:36:38Z pjf $
 
 use strict;
 use warnings;
 use base qw(HTML::FormWidgets);
 use English qw(-no_match_vars);
 use IO::File;
-use Readonly;
 use Syntax::Highlight::Perl;
 use Text::ParseWords;
 use Text::Tabs;
 
-use version; our $VERSION = qv( sprintf '0.1.%d', q$Rev: 33 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.2.%d', q$Rev: 95 $ =~ /\d+/gmx );
 
-Readonly my %SCHEME =>
+__PACKAGE__->mk_accessors( qw(base header hide path root scheme select
+                              style subtype) );
+
+my %SCHEME =
    ( Variable_Scalar   => [ '<font color="#CC6600">', '</font>' ],
      Variable_Array    => [ '<font color="#FFCC00">', '</font>' ],
      Variable_Hash     => [ '<font color="#990099">', '</font>' ],
@@ -38,30 +40,44 @@ Readonly my %SCHEME =>
      Label             => [ '<font color="#000000">', '</font>' ],
      Line              => [ '<font color="#000000">', '</font>' ], );
 
+sub init {
+   my ($self, $args) = @_;
+
+   $self->base(      q() );
+   $self->container( 0 );
+   $self->header(    [] );
+   $self->hide(      [] );
+   $self->path(      undef );
+   $self->root(      undef );
+   $self->scheme(    \%SCHEME );
+   $self->select(    -1 );
+   $self->style(     q() );
+   $self->subtype(   q(file) );
+
+   $self->NEXT::init( $args );
+   return;
+}
+
 sub _render {
    # Subtypes: file, csv, html, source, and logfile
-   my ($me, $ref) = @_;
-   my ($attr, $box, $cells, $c_no, $fld, $fmt, $htag, $key, $line);
+   my ($self, $args) = @_;
+   my ($attr, $box, $cells, $c_no, $fld, $fmt, $hacc, $key, $line);
    my ($pat, $path, $r_no, $rdr, $rows, $span, $text);
 
-   $me->header( [] )       unless (defined $me->header);
-   $me->select( -1 )       unless (defined $me->select);
-   $me->subtype( q(file) ) unless (defined $me->subtype);
+   $hacc = $self->hacc; $path = $self->path;
 
-   $htag = $me->elem; $path = $me->path;
-
-   if ($me->subtype eq q(html)) {
-      $pat   = $me->root;
+   if ($self->subtype eq q(html)) {
+      $pat = $self->root;
 
       if ($path =~ m{ \A $pat }msx) {
-         $path = $me->base.($path =~ s{ \A $pat }{/}msx);
+         $path = $self->base.($path =~ s{ \A $pat }{/}msx);
       }
 
-      $path  = $path =~ m{ \A http: }msx ? $path : $me->base.$path;
+      $path  = $path =~ m{ \A http: }msx ? $path : $self->base.$path;
       $text  = 'border: 0px; bottom: 0px; position: absolute; ';
-      $text .= 'top: 0px; width: 100%; height: 100%; '.$me->style;
+      $text .= 'top: 0px; width: 100%; height: 100%; '.$self->style;
 
-      return $htag->iframe( { src       => $path,
+      return $hacc->iframe( { src       => $path,
                               scrolling => q(auto),
                               style     => $text }, q(&nbsp;) );
    }
@@ -71,111 +87,112 @@ sub _render {
 
    $text = do { local $RS = undef; <$rdr> }; $rdr->close();
 
-   if ($me->subtype eq q(source)) {
+   if ($self->subtype eq q(source)) {
       $fmt = Syntax::Highlight::Perl->new();
-      $fmt->set_format( \%SCHEME );
+      $fmt->set_format( $self->scheme );
       $fmt->define_substitution( q(<) => q(&lt;),
                                  q(>) => q(&gt;),
                                  q(&) => q(&amp;) );
-      $tabstop = $me->tabstop;
-      $text    = expand( $text );
-      $text    = $fmt->format_string( $text );
+      $tabstop = $self->tabstop;
+      $text    = $fmt->format_string( expand( $text ) );
 
-      return $htag->pre( { class => $me->subtype }, $text );
+      return $hacc->pre( { class => $self->subtype }, $text );
    }
 
    $r_no = 0; $rows = q(); $span = 1;
 
-   if ($me->subtype eq q(logfile)) {
+   if ($self->subtype eq q(logfile)) {
       # TODO: Add Prev and next links to append div
       for $line (split m { \n }mx, $text) {
-         $line   = $htag->escape_html( $line, 0 );
-         $line   = $htag->pre( { class => $me->subtype }, $line );
-         $cells  = $htag->td(  { class => $me->subtype }, $line );
-         $rows  .= $htag->tr(  { class => $me->subtype }, $cells )."\n";
+         $line   = $hacc->escape_html( $line, 0 );
+         $line   = $hacc->pre( { class => $self->subtype }, $line );
+         $cells  = $hacc->td(  { class => $self->subtype }, $line );
+         $rows  .= $hacc->tr(  { class => $self->subtype }, $cells )."\n";
          $r_no++;
       }
 
-      $text = $htag->hidden( { name => q(nRows), value => $r_no } );
-      push @{ $me->hide }, $text;
+      push @{ $self->hide }, { name => q(nRows), value => $r_no };
 
-      return $htag->table( { cellpadding => 0, cellspacing => 0 }, $rows );
+      return $hacc->table( { cellpadding => 0, cellspacing => 0 }, $rows );
    }
 
    for $line (split m { \n }mx, $text) {
-      $line  = $htag->escape_html( $line, 0 );
+      $line  = $hacc->escape_html( $line, 0 );
       $cells = q(); $c_no = 0;
 
-      if ($me->subtype eq q(csv)) {
+      if ($self->subtype eq q(csv)) {
          for $fld (parse_line( q(,), 0, $line )) {
             if ($r_no == 0 && $line =~ m{ \A \# }mx) {
                $fld = substr $fld, 1 if ($c_no == 0);
-               $me->header->[ $c_no ] = $fld unless ($me->header->[ $c_no ]);
+
+               unless ($self->header->[ $c_no ]) {
+                  $self->header->[ $c_no ] = $fld;
+               }
             }
             else {
-               $attr   = { class => $me->subtype.q( ).($c_no % 2 == 0 ?
-                                                      q(even) : q(odd)) };
-               $cells .= $htag->td( $attr, $fld );
+               $attr   = { class => $self->subtype.q( ).($c_no % 2 == 0 ?
+                                                         q(even) : q(odd)) };
+               $cells .= $hacc->td( $attr, $fld );
             }
 
-            $key = $fld if ($c_no == $me->select);
+            $key = $fld if ($c_no == $self->select);
             $c_no++;
          }
 
          next if ($r_no == 0 && $line =~ m{ \A \# }msx);
       }
       else {
-         $cells .= $htag->td( { class => $me->subtype }, $line );
+         $cells .= $hacc->td( { class => $self->subtype }, $line );
          $c_no++;
       }
 
-      if ($me->select >= 0) {
-         $box   = $htag->checkbox( { label => q(),
+      if ($self->select >= 0) {
+         $box   = $hacc->checkbox( { label => q(),
                                      name  => q(select).$r_no,
                                      value => $key } );
-         $cells = $htag->td( { class => q(odd) }, $box ).$cells;
+         $cells = $hacc->td( { class => q(odd) }, $box ).$cells;
          $attr  = { class => q(lineNumber even) };
          $c_no++;
       }
       else { $attr = { class => q(lineNumber odd) } }
 
-      $cells = $htag->td( $attr, $r_no+1 ).$cells;
+      $cells = $hacc->td( $attr, $r_no+1 ).$cells;
       $c_no++;
 
       $span  = $c_no if ($c_no > $span);
-      $rows .= $htag->tr( { class => $me->subtype }, $cells );
+      $rows .= $hacc->tr( { class => $self->subtype }, $cells );
       $r_no++;
    }
 
-   $cells = $htag->th( { class => q(small table minimal) }, chr 35 );
+   $cells = $hacc->th( { class => q(small table minimal) }, chr 35 );
    $c_no  = 1;
 
-   if ($me->select >= 0) {
-      $cells .= $htag->th( { class => q(small table minimal) }, q(M) );
+   if ($self->select >= 0) {
+      $cells .= $hacc->th( { class => q(small table minimal) }, q(M) );
       $c_no++;
    }
 
-   if ($me->subtype eq q(csv)) {
-      if ($me->header->[0]) {
-         for $text (@{ $me->header }) {
-            $cells .= $htag->th( { class => q(small table) }, $text );
+   if ($self->subtype eq q(csv)) {
+      if ($self->header->[0]) {
+         for $text (@{ $self->header }) {
+            $cells .= $hacc->th( { class => q(small table) }, $text );
             last if (++$c_no >= $span);
          }
       }
       else {
          for $text ('A' .. 'Z') {
-            $cells .= $htag->th( { class => q(small table) }, $text );
+            $cells .= $hacc->th( { class => q(small table) }, $text );
             last if (++$c_no >= $span);
          }
       }
    }
-   else { $cells .= $htag->th( { class => q(small table) }, 'Lines' ) }
+   else { $cells .= $hacc->th( { class => q(small table) }, 'Lines' ) }
 
-   $rows  = $htag->tr( $cells ).$rows;
+   $rows  = $hacc->tr( $cells ).$rows;
 
-   push @{ $me->hide }, $htag->hidden( { name => q(nRows), value => $r_no } );
+   push @{ $self->hide }, { name  => q(nRows), value => $r_no };
 
-   return $htag->table( $rows );
+   return $hacc->table( $rows );
 }
 
 1;
